# imgpro

**Description**

The imgpro package has the following tools:

Processing:
- Histogram matching
- Structural similarity
- Resizing images

Utils:
- Reading images
- Saving images
- Plotting images
- Plotting similarity tests
- Plotting rgb histograms

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install imgpro

    pip install imgpro


## Usage

    from image_processing.processing import combination.py
    combination.find_difference()

## Author
Marianne Costa Avalone

## License
[MIT](https://chosealicense.com/licenses/mit/)